v1

package
v0.0.0-...-7136e67 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 12, 2021 License: MIT Imports: 8 Imported by: 0

Documentation

Overview

This package has the automatically generated typed clients.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MetaDataContextTypeExpansion

type MetaDataContextTypeExpansion interface{}

type MetaDataContextTypeInterface

type MetaDataContextTypeInterface interface {
	Create(ctx context.Context, metaDataContextType *v1.MetaDataContextType, opts metav1.CreateOptions) (*v1.MetaDataContextType, error)
	Update(ctx context.Context, metaDataContextType *v1.MetaDataContextType, opts metav1.UpdateOptions) (*v1.MetaDataContextType, error)
	UpdateStatus(ctx context.Context, metaDataContextType *v1.MetaDataContextType, opts metav1.UpdateOptions) (*v1.MetaDataContextType, error)
	Delete(ctx context.Context, name string, opts metav1.DeleteOptions) error
	DeleteCollection(ctx context.Context, opts metav1.DeleteOptions, listOpts metav1.ListOptions) error
	Get(ctx context.Context, name string, opts metav1.GetOptions) (*v1.MetaDataContextType, error)
	List(ctx context.Context, opts metav1.ListOptions) (*v1.MetaDataContextTypeList, error)
	Watch(ctx context.Context, opts metav1.ListOptions) (watch.Interface, error)
	Patch(ctx context.Context, name string, pt types.PatchType, data []byte, opts metav1.PatchOptions, subresources ...string) (result *v1.MetaDataContextType, err error)
	MetaDataContextTypeExpansion
}

MetaDataContextTypeInterface has methods to work with MetaDataContextType resources.

type MetaDataContextTypesGetter

type MetaDataContextTypesGetter interface {
	MetaDataContextTypes(namespace string) MetaDataContextTypeInterface
}

MetaDataContextTypesGetter has a method to return a MetaDataContextTypeInterface. A group's client should implement this interface.

type MetadataV1Client

type MetadataV1Client struct {
	// contains filtered or unexported fields
}

MetadataV1Client is used to interact with features provided by the metadata.cloudskunkworks group.

func New

New creates a new MetadataV1Client for the given RESTClient.

func NewForConfig

func NewForConfig(c *rest.Config) (*MetadataV1Client, error)

NewForConfig creates a new MetadataV1Client for the given config.

func NewForConfigOrDie

func NewForConfigOrDie(c *rest.Config) *MetadataV1Client

NewForConfigOrDie creates a new MetadataV1Client for the given config and panics if there is an error in the config.

func (*MetadataV1Client) MetaDataContextTypes

func (c *MetadataV1Client) MetaDataContextTypes(namespace string) MetaDataContextTypeInterface

func (*MetadataV1Client) RESTClient

func (c *MetadataV1Client) RESTClient() rest.Interface

RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.

type MetadataV1Interface

type MetadataV1Interface interface {
	RESTClient() rest.Interface
	MetaDataContextTypesGetter
}

Directories

Path Synopsis
Package fake has the automatically generated clients.
Package fake has the automatically generated clients.

Jump to