v1

package
v0.0.0-...-7136e67 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 12, 2021 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type MetaDataContextTypeLister

type MetaDataContextTypeLister interface {
	// List lists all MetaDataContextTypes in the indexer.
	// Objects returned here must be treated as read-only.
	List(selector labels.Selector) (ret []*v1.MetaDataContextType, err error)
	// MetaDataContextTypes returns an object that can list and get MetaDataContextTypes.
	MetaDataContextTypes(namespace string) MetaDataContextTypeNamespaceLister
	MetaDataContextTypeListerExpansion
}

MetaDataContextTypeLister helps list MetaDataContextTypes. All objects returned here must be treated as read-only.

func NewMetaDataContextTypeLister

func NewMetaDataContextTypeLister(indexer cache.Indexer) MetaDataContextTypeLister

NewMetaDataContextTypeLister returns a new MetaDataContextTypeLister.

type MetaDataContextTypeListerExpansion

type MetaDataContextTypeListerExpansion interface{}

MetaDataContextTypeListerExpansion allows custom methods to be added to MetaDataContextTypeLister.

type MetaDataContextTypeNamespaceLister

type MetaDataContextTypeNamespaceLister interface {
	// List lists all MetaDataContextTypes in the indexer for a given namespace.
	// Objects returned here must be treated as read-only.
	List(selector labels.Selector) (ret []*v1.MetaDataContextType, err error)
	// Get retrieves the MetaDataContextType from the indexer for a given namespace and name.
	// Objects returned here must be treated as read-only.
	Get(name string) (*v1.MetaDataContextType, error)
	MetaDataContextTypeNamespaceListerExpansion
}

MetaDataContextTypeNamespaceLister helps list and get MetaDataContextTypes. All objects returned here must be treated as read-only.

type MetaDataContextTypeNamespaceListerExpansion

type MetaDataContextTypeNamespaceListerExpansion interface{}

MetaDataContextTypeNamespaceListerExpansion allows custom methods to be added to MetaDataContextTypeNamespaceLister.

Jump to