v1

package
v0.0.0-...-7136e67 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Apr 12, 2021 License: MIT Imports: 3 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

var (
	SchemeBuilder runtime.SchemeBuilder

	AddToScheme = localSchemeBuilder.AddToScheme
)
var SchemeGroupVersion = schema.GroupVersion{
	Group:   "metadata.cloudskunkworks",
	Version: "v1",
}

Define your schema name and the version

Functions

func Resource

func Resource(resource string) schema.GroupResource

Resource takes an unqualified resource and returns a Group qualified GroupResource

Types

type MetaDataContextSpec

type MetaDataContextSpec struct {
	DataMapping Values `json:"datamapping,omitempty"`
}

custom spec

func (*MetaDataContextSpec) DeepCopy

func (in *MetaDataContextSpec) DeepCopy() *MetaDataContextSpec

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MetaDataContextSpec.

func (*MetaDataContextSpec) DeepCopyInto

func (in *MetaDataContextSpec) DeepCopyInto(out *MetaDataContextSpec)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type MetaDataContextType

type MetaDataContextType struct {
	metav1.TypeMeta `json:",inline"`
	// +optional
	metav1.ObjectMeta `json:"metadata,omitempty"`
	// +optional
	Status MetaDataContextTypeStatus `json:"status,omitempty"`
	// This is where you can define
	// your own custom spec
	Spec MetaDataContextSpec `json:"spec,omitempty"`
}

MetaDataContextType is a top-level type

func (*MetaDataContextType) DeepCopy

func (in *MetaDataContextType) DeepCopy() *MetaDataContextType

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MetaDataContextType.

func (*MetaDataContextType) DeepCopyInto

func (in *MetaDataContextType) DeepCopyInto(out *MetaDataContextType)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*MetaDataContextType) DeepCopyObject

func (in *MetaDataContextType) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type MetaDataContextTypeList

type MetaDataContextTypeList struct {
	metav1.TypeMeta `json:",inline"`
	// +optional
	metav1.ListMeta `son:"metadata.cloudskunkworks,omitempty"`

	Items []MetaDataContextType `json:"items"`
}

no client needed for list as it's been created in above

func (*MetaDataContextTypeList) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MetaDataContextTypeList.

func (*MetaDataContextTypeList) DeepCopyInto

func (in *MetaDataContextTypeList) DeepCopyInto(out *MetaDataContextTypeList)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

func (*MetaDataContextTypeList) DeepCopyObject

func (in *MetaDataContextTypeList) DeepCopyObject() runtime.Object

DeepCopyObject is an autogenerated deepcopy function, copying the receiver, creating a new runtime.Object.

type MetaDataContextTypeStatus

type MetaDataContextTypeStatus struct {
	Name string
}

custom status

func (*MetaDataContextTypeStatus) DeepCopy

DeepCopy is an autogenerated deepcopy function, copying the receiver, creating a new MetaDataContextTypeStatus.

func (*MetaDataContextTypeStatus) DeepCopyInto

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

type Values

type Values map[string]interface{}

func (*Values) DeepCopy

func (v *Values) DeepCopy() *Values

func (Values) DeepCopyInto

func (in Values) DeepCopyInto(out *Values)

DeepCopyInto is an autogenerated deepcopy function, copying the receiver, writing into out. in must be non-nil.

Jump to