Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ISubscription ¶
type ISubscription interface {
OnEvent(msg Message)
WithElectedResource() interface{}
// Return an empty array for all event types or selective set an event type to filter for
//Added EventType = "ADDED"
//Modified EventType = "MODIFIED"
//Deleted EventType = "DELETED"
//Bookmark EventType = "BOOKMARK"
//Error EventType = "ERROR"
WithEventType() []watch.EventType
}
Click to show internal directories.
Click to hide internal directories.